OC.L10N.register(
    "contacts",
    {
    "Contacts" : "アドレス帳",
    "No contacts in here" : "連絡先がありません",
    "Name" : "名前",
    "Organization" : "所属",
    "Title" : "タイトル",
    "Add field ..." : "項目を追加",
    "Add contact" : "連絡先を追加",
    "No search result for {query}" : "{query} に関する検索結果はありません。",
    "All contacts" : "すべての連絡先",
    "Not grouped" : "グループ化されていません",
    "Post Office Box" : "私書箱",
    "Postal Code" : "郵便番号",
    "City" : "市町村",
    "State or province" : "州／県",
    "Country" : "国名",
    "Address" : "アドレス",
    "(new group)" : "(新規グループ)",
    "{addressbook} shared by {owner}" : " {owner}と共有中の{addressbook} ",
    "Nickname" : "ニックネーム",
    "Notes" : "ノート",
    "Website" : "ウェブサイト",
    "Federated Cloud ID" : "統合されたクラウドID",
    "Home" : "自宅",
    "Work" : "職場",
    "Other" : "その他",
    "Groups" : "グループ",
    "Birthday" : "誕生日",
    "Email" : "メール",
    "Instant messaging" : "インスタントメッセージ",
    "Phone" : "電話番号",
    "Mobile" : "携帯",
    "Fax" : "FAX",
    "Fax home" : "自宅FAX",
    "Fax work" : "職場FAX",
    "Pager" : "ポケベル",
    "Voice" : "音声番号",
    "Settings" : "設定",
    "Import" : "インポート"
},
"nplurals=1; plural=0;");
